households.MembersByPerson (Household memberships) — amici1

# `households.MembersByPerson` (Household memberships)

Columns

- `<django.db.models.fields.BigAutoField: id>`

- `<django.db.models.fields.DateField: start_date>`

- `<django.db.models.fields.DateField: end_date>`

- `<django.db.models.fields.CharField: title>`

- `<django.db.models.fields.CharField: first_name>`

- `<django.db.models.fields.CharField: middle_name>`

- `<django.db.models.fields.CharField: last_name>`

- `<lino.core.choicelists.ChoiceListField: gender>`

- `<lino.core.fields.IncompleteDateField: birth_date>`

- `<lino.core.choicelists.ChoiceListField: role>`

- `<django.db.models.fields.related.ForeignKey: person>`

- `<django.db.models.fields.related.ForeignKey: household>`

- `<lino.core.choicelists.ChoiceListField: dependency>`

- `<django.db.models.fields.BooleanField: primary>`

- `lino_xl.lib.households.models.Member.age`

- `lino_xl.lib.households.models.Member.age`

Actions

- HTML (show_as_html) : Show this table in Bootstrap3 interface

- Table (landscape) (as_pdf) : Show this table as a pdf document.

- Table (portrait) (as_pdf_p) : Show this table as a pdf document.

- Export to .xls (export_excel) : Export this table as an .xls document

- None (grid_post) : See `<lino.core.actions.CreateRow grid_post>`.

- None (grid_put) : See `<lino.core.actions.SaveGridCell grid_put>`.

- New (insert) : Open a dialog window to insert a new Household Member.

- Create (submit_insert) : Create the record and open a detail window on it

- Delete (delete_selected) : Delete this record

- None (grid) : See `<lino.core.actions.ShowTable grid>`.

- None (open_help) : See `<lino.core.actions.OpenHelpWindow open_help>`.

- None (set_primary) : Make this the primary household.

Filter parameters

- `<django.db.models.fields.DateField: start_date>`

- `<django.db.models.fields.DateField: end_date>`

- `<django.db.models.fields.IntegerField: aged_from>`

- `<django.db.models.fields.IntegerField: aged_to>`

- `<lino.core.choicelists.ChoiceListField: gender>`

## Filter parameters